@@ -20,9 +20,9 @@
 #define __AVICORE_H__
 
 
-#include "common.h"
-#include "bitmap.h"
+#include "gcommon.h"
 #include "wave.h"
+#include "misc/bitmap.h"
 
 
 #ifdef __cplusplus
