@@ -1,6 +1,6 @@
 /*
     avicore
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -128,12 +128,7 @@ typedef struct _AviBaseIndex
   guint8 type __attribute__((packed));
   guint32 entries __attribute__((packed));
   guint32 ckid __attribute__((packed));
-#ifdef G_HAVE_GINT64
   guint64 offset __attribute__((packed));
-#else /* not G_HAVE_GINT64 */
-  guint32 offset_low __attribute__((packed));
-  guint32 offset_hi __attribute__((packed));
-#endif /* not G_HAVE_GINT64 */
   guint32 reserveed __attribute__((packed));
 } AviBaseIndex;
 typedef AviBaseIndex AviFieldIndex;
@@ -154,12 +149,7 @@ typedef struct _AviFieldIndexEntry
 /* en:AVI Super Index Entry */
 typedef struct _AviSuperIndexEntry
 {
-#ifdef G_HAVE_GINT64
   guint64 offset __attribute__((packed));
-#else /* not G_HAVE_GINT64 */
-  guint32 offset_low __attribute__((packed));
-  guint32 offset_hi __attribute__((packed));
-#endif /* not G_HAVE_GINT64 */
   guint32 size __attribute__((packed));
   guint32 duration __attribute__((packed));
 } AviSuperIndexEntry;
@@ -314,9 +304,7 @@ typedef struct { guint8 dummy[DML_SIZE]; } ODMLExtendedAVIHeader;
 #define abi_get_offset_hi(abi)                                              \
                             GUINT32_FROM_LE(*(guint32 *)((guint8 *)(abi)+16))
 #define abi_get_reserve(abi) GUINT32_FROM_LE(*(guint32 *)((guint8 *)(abi)+20))
-#ifdef G_HAVE_GINT64
-# define abi_get_offset(abi) GUINT64_FROM_LE(*(guint64 *)((guint8 *)(abi)+12))
-#endif /* G_HAVE_GINT64 */
+#define abi_get_offset(abi) GUINT64_FROM_LE(*(guint64 *)((guint8 *)(abi)+12))
 
 #define abi_set_longs(abi,longs) (*(guint16 *)(abi)=GUINT16_TO_LE(longs))
 #define abi_set_sub_type(abi,sub_type) (*((guint8 *)(abi)+2)=(sub_type))
@@ -331,10 +319,8 @@ typedef struct { guint8 dummy[DML_SIZE]; } ODMLExtendedAVIHeader;
                     (*(guint32 *)((guint8 *)(abi)+16)=GUINT32_TO_LE(offset_hi))
 #define abi_set_reserve(abi,reserve)                                        \
                     (*(guint32 *)((guint8 *)(abi)+20)=GUINT32_TO_LE(reserve))
-#ifdef G_HAVE_GINT64
-# define abi_set_offset(abi,offset)                                         \
+#define abi_set_offset(abi,offset)                                         \
                     (*(guint64 *)((guint8 *)(abi)+12)=GUINT64_TO_LE(offset))
-#endif /* G_HAVE_GINT64 */
 
 
 #define afi_get_longs abi_get_longs
@@ -345,9 +331,7 @@ typedef struct { guint8 dummy[DML_SIZE]; } ODMLExtendedAVIHeader;
 #define afi_get_offset_low abi_get_offset_low
 #define afi_get_offset_hi abi_get_offset_hi
 #define afi_get_reserve abi_get_reserve
-#ifdef G_HAVE_GINT64
-# define afi_get_offset abi_get_offset
-#endif /* G_HAVE_GINT64 */
+#define afi_get_offset abi_get_offset
 
 #define afi_set_longs abi_set_longs
 #define afi_set_sub_type abi_set_sub_type
@@ -357,9 +341,7 @@ typedef struct { guint8 dummy[DML_SIZE]; } ODMLExtendedAVIHeader;
 #define afi_set_offset_low abi_set_offset_low
 #define afi_set_offset_hi abi_set_offset_hi
 #define afi_set_reserve abi_set_reserve
-#ifdef G_HAVE_GINT64
-# define afi_set_offset abi_set_offset
-#endif /* G_HAVE_GINT64 */
+#define afi_set_offset abi_set_offset
 
 
 #define asi_get_longs abi_get_longs
@@ -404,9 +386,7 @@ typedef struct { guint8 dummy[DML_SIZE]; } ODMLExtendedAVIHeader;
 #define ase_get_offset_hi(ase) GUINT32_FROM_LE(*(guint32 *)((guint8 *)(ase)+4))
 #define ase_get_size(ase) GUINT32_FROM_LE(*(guint32 *)((guint8 *)(ase)+8))
 #define ase_get_duration(ase) GUINT32_FROM_LE(*(guint32 *)((guint8 *)(ase)+12))
-#ifdef G_HAVE_GINT64
-# define ase_get_offset(ase) GUINT64_FROM_LE(*(guint64 *)(ase))
-#endif /* G_HAVE_GINT64 */
+#define ase_get_offset(ase) GUINT64_FROM_LE(*(guint64 *)(ase))
 
 #define ase_set_offset_low(ase,offset_low)                                  \
                         (*(guint32 *)(ase)=GUINT32_TO_LE(offset_low))
@@ -416,9 +396,7 @@ typedef struct { guint8 dummy[DML_SIZE]; } ODMLExtendedAVIHeader;
                         (*(guint32 *)((guint8 *)(ase)+8)=GUINT32_TO_LE(size))
 #define ase_set_duration(ase,duration)                                      \
                     (*(guint32 *)((guint8 *)(ase)+12)=GUINT32_TO_LE(duration))
-#ifdef G_HAVE_GINT64
-# define ase_set_offset(ase,offset) (*(guint64 *)(ase)=GUINT64_TO_LE(offset))
-#endif /* G_HAVE_GINT64 */
+#define ase_set_offset(ase,offset) (*(guint64 *)(ase)=GUINT64_TO_LE(offset))
 
 
 #define dml_get_total_frames(dml) GUINT32_FROM_LE(*(guint32 *)(dml))
