@@ -20,7 +20,7 @@
 #include "avifmt.h"
 #include "chunk.h"
 #include "gsrfmt.h"
-#include "pixbuf.h"
+#include "misc/pixbuf.h"
 
 
 /******************************************************************************
