@@ -118,19 +118,20 @@ avi_play_set_position_internal (AviPlay    *play,
   play->position = position;
   if (redraw)
     {
-      GdkRectangle rc;
+      gint width, height;
 
-      rc.width = MIN (avi_edit_get_width (play->avi_edit[0])
+      width = MIN (avi_edit_get_width (play->avi_edit[0])
                                     * play->drawing->allocation.height
                                     / avi_edit_get_height (play->avi_edit[0]),
                                             play->drawing->allocation.width);
-      rc.height = MIN (avi_edit_get_height (play->avi_edit[0])
+      height = MIN (avi_edit_get_height (play->avi_edit[0])
                                     * play->drawing->allocation.width
                                     / avi_edit_get_width (play->avi_edit[0]),
                                             play->drawing->allocation.height);
-      rc.x = (play->drawing->allocation.width - rc.width) / 2;
-      rc.y = (play->drawing->allocation.height - rc.height) / 2;
-      gtk_widget_draw (play->drawing, &rc);
+      gtk_widget_queue_draw_area (play->drawing,
+                            (play->drawing->allocation.width - width) / 2,
+                            (play->drawing->allocation.height - height) / 2,
+                                                                width, height);
     }
   if (play->hbox)
     {
@@ -263,7 +264,7 @@ avi_play_expose (GtkWidget      *widget,
         gdk_draw_rgb_32_image (widget->window, gc, x, y, width, height,
                                         GDK_RGB_DITHER_NORMAL, buf, width * 4);
     }
-  gdk_gc_destroy (gc);
+  g_object_unref (gc);
   return TRUE;
 }
 
@@ -1385,7 +1386,7 @@ avi_play_set_handle (AviPlay  *play,
   gtk_range_set_range (GTK_RANGE (play->hscale), 0, MAX (play->length - 1, 1));
   gtk_widget_set_sensitive (play->hscale, !play->playing && play->length > 1);
   avi_play_set_position_internal (play, 0);
-  gtk_widget_draw (play->drawing, NULL);
+  gtk_widget_queue_draw (play->drawing);
 }
 
 
@@ -1529,7 +1530,7 @@ avi_play_stop (AviPlay *play)
   play->playing = FALSE;
   if (play->timer_id != 0)
     {
-      gtk_timeout_remove (play->timer_id);
+      g_source_remove (play->timer_id);
       play->timer_id = 0;
     }
 #ifdef USE_LIBAO
