@@ -1,6 +1,6 @@
 /*
     avicore
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 #define __ICM_H__
 
 
-#include "bitmap.h"
+#include "misc/bitmap.h"
 
 
 #ifdef __cplusplus
