@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -230,6 +230,11 @@ command_save (GtkWidget *widget,
   cmd_ok.avi_save = NULL;
   cmd_ok.extra = avi_extra_new ();
   avi_extra_set_handle (AVI_EXTRA (cmd_ok.extra), avi_edit);
+  if (vmaid->avi_edit[0])
+    avi_extra_set_range (AVI_EXTRA (cmd_ok.extra),
+        MIN (vmaid->cursor.frame, avi_edit_length (avi_edit[0]) - 1),
+        MIN (vmaid->select.stream < 0 ? vmaid->cursor.frame
+                    : vmaid->select.frame, avi_edit_length (avi_edit[0]) - 1));
   cmd_ok.check = gtk_check_button_new_with_mnemonic
                                         (_("_Automatic file name extension"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (cmd_ok.check), addext);
@@ -317,20 +322,12 @@ command_save (GtkWidget *widget,
             {
               const gchar *ext;
 
-              switch (avi_save_type (cmd_ok.avi_save))
-                {
-                  case AVI_FILE_AVI:      ext = ".avi"; break;
-                  case AVI_FILE_GSR:      ext = ".gsr"; break;
-                  case AVI_FILE_BITMAP:   ext = ".bmp"; break;
-                  case AVI_FILE_WAVE:     ext = ".wav"; break;
-                  case AVI_FILE_SCENARIO: ext = ".scn"; break;
-                  default:                ext = NULL;
-                }
+              ext = avi_save_get_extension (cmd_ok.avi_save);
               if (ext)
                 {
                   gchar *tmp;
 
-                  tmp = g_strconcat (cmd_ok.file, ext, NULL);
+                  tmp = g_strconcat (cmd_ok.file, ".", ext, NULL);
                   g_free (cmd_ok.file);
                   cmd_ok.file = tmp;
                 }
@@ -471,7 +468,7 @@ command_property (GtkWidget *widget,
         vmaid->top = MAX (vmaid->cursor.frame - sx, 0);
       /* ja:メニュー,ステートメント,子ウインドウ */
       set_menu_bar (vmaid);
-      gtk_widget_draw (vmaid->drawing, NULL);
+      gtk_widget_queue_draw (vmaid->drawing);
       draw_caret (vmaid, NULL);
       misc_set_scroll_bar (vmaid->hscroll,
                                     G_CALLBACK (signal_value_changed_hscroll),
