@@ -143,6 +143,9 @@ version_dialog (void)
 "Packager:\n"
 " yasuo-s\n"
 "\n"
+"w32loader:\n"
+" Inspired by Wine\n"
+"\n"
 "Special Thanks:\n"
 " MINAMI Hirokazu\n"
 " Takuro Ashie\n"
