@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -31,9 +31,7 @@
 #include "misc/fileio.h"
 #include "misc/gnugpl.h"
 #include "misc/license.h"
-#if ! GLIB_CHECK_VERSION(2,6,0)
-# include "misc/profile.h"
-#endif /* not GLIB_CHECK_VERSION(2,6,0) */
+#include "misc/profile.h"
 #include "orz/orzaccel.h"
 #include "orz/orzcomm.h"
 #include "orz/orzhistory.h"
@@ -63,9 +61,8 @@ GtkWidget *window;                  /* ja:ウインドウ */
 GtkWidget *mdi;                     /* en:MDI */
 GtkWidget *tview;                   /* ja:リストボックス */
 GtkWidget *status;                  /* ja:ステータスウインドウ */
-GdkFont *system_font = NULL;
-gint system_font_height;            /* ja:フォントの高さ */
-gint system_font_ascent;            /* ja:フォントのアクセントの高さ */
+PangoLayout *system_font_layout = NULL;
+gint system_font_height = 1;        /* ja:フォントの高さ */
 GdkColor system_color[4] = {{0, 0x0000, 0x0000, 0x0000},
                             {0, 0xffff, 0xffff, 0xffff},
                             {0, 0x8000, 0x8000, 0x8000},
@@ -189,7 +186,7 @@ main (int   argc,
   GtkTreeSelection *select;
   GtkTreeViewColumn *column;
   GtkWidget *text, *handle, *scroll, *vbox;
-  /* en:Drag&Drop */
+  /* en:Drag and Drop */
   GtkTargetEntry drag_types[1] = {{"text/uri-list", 0, 0}};
   static gchar *xpm0[] = {
 "4 8 2 1",
@@ -209,7 +206,23 @@ main (int   argc,
 ".  c #000000",
 ". ",
 " ."};
-
+  /* ja:コマンドライン */
+  gint array[2], def[2];
+  ArgumentBool arg_n, arg_p, arg_x;
+  ArgumentValue arg_h;
+  ArgumentArray arg_s;
+  ArgumentExit arg_g, arg_v;
+  ArgumentHelp arg_q;
+  ArgumentList arg_opts[] = {
+{"history", 'h',  "NUM",          N_("History"),                    ARGUMENT_TYPE_VALUE, &arg_h},
+{"new",     'n',  "ON/OFF",       N_("New File"),                   ARGUMENT_TYPE_BOOL,  &arg_n},
+{"profile", 'p',  "ON/OFF",       N_("Profile"),                    ARGUMENT_TYPE_BOOL,  &arg_p},
+{"size",    's',  "WIDTH,HEIGHT", N_("Window Size"),                ARGUMENT_TYPE_ARRAY, &arg_s},
+{"second",  'x',  "ON/OFF",       N_("Open Window"),                ARGUMENT_TYPE_BOOL,  &arg_x},
+{"license", 'g',  NULL,           N_("GNU GENERAL PUBLIC LICENSE"), ARGUMENT_TYPE_EXIT,  &arg_g},
+{"version", 'v',  NULL,           N_("About"),                      ARGUMENT_TYPE_EXIT,  &arg_v},
+{"help",    '?',  NULL,           N_("Help"),                       ARGUMENT_TYPE_HELP,  &arg_q},
+{NULL,      '\0', NULL,           NULL,                             0,                   NULL}};
 
   /* ja:初期化 */
   setlocale (LC_ALL, "");
@@ -219,7 +232,6 @@ main (int   argc,
 #endif /* USE_THREAD */
   gtk_set_locale ();
   gtk_init (&argc, &argv);
-  gdk_rgb_init ();
   bindtextdomain (PACKAGE, misc_spec_locale (argv[0]));
   bind_textdomain_codeset (PACKAGE, "UTF-8");
   textdomain (PACKAGE);
@@ -289,63 +301,53 @@ main (int   argc,
   if (license_hash (gnugpl) != license)
     license = license_dialog (gnugpl);
   if (license < 0)
-    gtk_exit (0);
+    return 0;
 
-  /* ja:コマンドラインの解析 */
-  {
-    gint array[2], def[2];
-    ArgumentBool arg_n, arg_p, arg_x;
-    ArgumentValue arg_h;
-    ArgumentArray arg_s;
-    ArgumentExit arg_v;
-    ArgumentHelp arg_q;
-    ArgumentList arg_opts[] = {
-{"history", 'h',  "NUM",          N_("History"),     ARGUMENT_TYPE_VALUE, &arg_h},
-{"new",     'n',  "ON/OFF",       N_("New File"),    ARGUMENT_TYPE_BOOL,  &arg_n},
-{"profile", 'p',  "ON/OFF",       N_("Profile"),     ARGUMENT_TYPE_BOOL,  &arg_p},
-{"size",    's',  "WIDTH,HEIGHT", N_("Window Size"), ARGUMENT_TYPE_ARRAY, &arg_s},
-{"second",  'x',  "ON/OFF",       N_("Open Window"), ARGUMENT_TYPE_BOOL,  &arg_x},
-{"version", 'v',  NULL,           N_("About"),       ARGUMENT_TYPE_EXIT,  &arg_v},
-{"help",    '?',  NULL,           N_("Help"),        ARGUMENT_TYPE_HELP,  &arg_q},
-{NULL,      '\0', NULL,           NULL,              0,                   NULL}};
-
-    /* ja:ファイルの履歴 */
-    arg_h.val = orz_history_get_num (ORZ_HISTORY (history));
-    arg_h.def = ORZ_HISTORY_NUM_DEF;
-    /* ja:新規ファイル */
-    arg_n.flag = newfile;
-    arg_n.def = FALSE;
-    /* ja:レジストリ */
-    arg_p.flag = TRUE;
-    arg_p.def = TRUE;
-    /* ja:ウインドウサイズ */
-    array[0] = def_width;
-    array[1] = def_height;
-    def[0] = gdk_screen_width () * 2 / 3;
-    def[1] = gdk_screen_height () * 2 / 3;
-    arg_s.leng = 2;
-    arg_s.array = array;
-    arg_s.def = def;
-    /* ja:新規ウインドウ */
-    arg_x.flag = second;
-    arg_x.def = FALSE;
-    /* ja:バージョン */
-    arg_v.str =
+  /* ja:コマンドライン */
+  /* ja:ファイルの履歴 */
+  arg_h.val = orz_history_get_num (ORZ_HISTORY (history));
+  arg_h.def = ORZ_HISTORY_NUM_DEF;
+  /* ja:新規ファイル */
+  arg_n.flag = newfile;
+  arg_n.def = FALSE;
+  /* ja:レジストリ */
+  arg_p.flag = TRUE;
+  arg_p.def = TRUE;
+  /* ja:ウインドウサイズ */
+  array[0] = def_width;
+  array[1] = def_height;
+  def[0] = gdk_screen_width () * 2 / 3;
+  def[1] = gdk_screen_height () * 2 / 3;
+  arg_s.leng = 2;
+  arg_s.array = array;
+  arg_s.def = def;
+  /* ja:新規ウインドウ */
+  arg_x.flag = second;
+  arg_x.def = FALSE;
+  /* ja:ライセンス */
+  arg_g.str = gnugpl;
+  /* ja:バージョン */
+  arg_v.str =
 VMAID_VERSION_NOTICE"\n"
 VMAID_COPYRIGHT_NOTICE"\n"
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n";
-    /* ja:ヘルプ */
-    arg_q.str = VMAID_COPYRIGHT_NOTICE"\n\n";
-    arg_files = arg_analyse (argv, arg_opts);
-    orz_history_set_num (ORZ_HISTORY (history), arg_h.val);
-    newfile = arg_n.flag;
-    if (!arg_p.flag)
-      user_config = NULL;
-    def_width = array[0];
-    def_height = array[1];
-    second = arg_x.flag;
-  }
+  /* ja:ヘルプ */
+  arg_q.str = VMAID_COPYRIGHT_NOTICE"\n\n";
+  /* ja:コマンドラインの解析 */
+  arg_files = arg_analyse (argv, arg_opts);
+  /* ja:ファイルの履歴 */
+  orz_history_set_num (ORZ_HISTORY (history), arg_h.val);
+  /* ja:新規ファイル */
+  newfile = arg_n.flag;
+  /* ja:レジストリ */
+  if (!arg_p.flag)
+    user_config = NULL;
+  /* ja:ウインドウサイズ */
+  def_width = array[0];
+  def_height = array[1];
+  /* ja:新規ウインドウ */
+  second = arg_x.flag;
 
   /* ja:メインウインドウ */
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
@@ -367,9 +369,8 @@ VMAID_COPYRIGHT_NOTICE"\n"
                                             G_CALLBACK (gtk_main_quit), NULL);
   gtk_widget_realize (window);
   /* en:Drag and Drop */
-  gtk_drag_dest_set (window, GTK_DEST_DEFAULT_MOTION
-                        | GTK_DEST_DEFAULT_HIGHLIGHT | GTK_DEST_DEFAULT_DROP,
-                                            drag_types, 1, GDK_ACTION_COPY);
+  gtk_drag_dest_set (window, GTK_DEST_DEFAULT_ALL,
+                    drag_types, G_N_ELEMENTS (drag_types), GDK_ACTION_COPY);
   g_signal_connect (G_OBJECT (window), "drag-data-received",
                                 G_CALLBACK (signal_drag_data_received), NULL);
   /* ja:クリップボード */
@@ -380,6 +381,10 @@ VMAID_COPYRIGHT_NOTICE"\n"
   mdi = orz_mdi_new ();
   gtk_notebook_set_scrollable (GTK_NOTEBOOK (mdi), TRUE);
   gtk_notebook_set_tab_pos (GTK_NOTEBOOK (mdi), n_pos);
+  gtk_drag_dest_set (mdi, GTK_DEST_DEFAULT_ALL,
+                    drag_types, G_N_ELEMENTS (drag_types), GDK_ACTION_COPY);
+  g_signal_connect (G_OBJECT (mdi), "drag-data-received",
+                                G_CALLBACK (signal_drag_data_received), NULL);
   g_signal_connect (G_OBJECT (mdi), "close-window",
                                 G_CALLBACK (signal_close_window), NULL);
   g_signal_connect (G_OBJECT (mdi), "switch-window",
@@ -542,7 +547,7 @@ VMAID_COPYRIGHT_NOTICE"\n"
       if (!orz_comm_is_first (ORZ_COMM (comm)))
         {
           orz_comm_send_with_files (ORZ_COMM (comm), argc, argv, arg_files);
-          gtk_exit (0);
+          return 0;
         }
       g_signal_connect (G_OBJECT (comm), "recv",
                                     G_CALLBACK (signal_selection_recv), NULL);
@@ -550,7 +555,7 @@ VMAID_COPYRIGHT_NOTICE"\n"
 
   /* ja:表示 */
   gtk_widget_show_all (window);
-  gtk_widget_hide_all (text);
+  gtk_widget_hide (text);
 
   /* ja:ピクスマップ */
   pixmap = gdk_pixmap_create_from_xpm_d (window->window, &bitmap0, NULL, xpm0);
@@ -567,19 +572,17 @@ VMAID_COPYRIGHT_NOTICE"\n"
   gdk_colormap_alloc_colors (gdk_colormap_get_system (),
                                         system_color, 4, FALSE, TRUE, success);
   /* ja:システムフォント */
-  system_font = gdk_font_ref (gtk_style_get_font (style));
-  for (i = 0; i < 256; i++)
-    {
-      gint ascent, height;
+  system_font_layout = gtk_widget_create_pango_layout (text, NULL);
+  for (i = 0; i < 128; i++)
+    if (g_unichar_isprint ((gunichar)i))
+      {
+        int w, h;
 
-      gdk_text_extents (system_font, (gchar *)&i, 1,
-                                            NULL, NULL, NULL, &ascent, NULL);
-      if (system_font_ascent < ascent)
-        system_font_ascent = ascent;
-      height = gdk_char_height (system_font, (gchar)i);
-      if (system_font_height < height)
-        system_font_height = height;
-    }
+        pango_layout_set_text (system_font_layout, (const char *)&i, 1);
+        pango_layout_get_pixel_size (system_font_layout, &w, &h);
+        if (system_font_height < h)
+          system_font_height = h;
+      }
 
   /* ja:新規ウインドウ */
   count = 0;
@@ -695,9 +698,8 @@ VMAID_COPYRIGHT_NOTICE"\n"
         }
     }
 
-  gdk_font_unref (system_font);
+  g_object_unref (system_font_layout);
   g_free (open_path);
   g_free (save_path);
-  gtk_exit (0);
   return 0;
 }
