@@ -277,6 +277,9 @@ extern "C" {
 #define SPI_GETSCREENSAVERRUNNING 114
 #define SPI_GETDESKWALLPAPER      115
 
+/* ja:タイマ */
+typedef VOID CALLBACK (*TIMERPROC)(HWND, UINT, UINT, DWORD);
+
 /* ja:描画 */
 #include "pshpack1.h"
 typedef struct _POINT
@@ -447,7 +450,9 @@ typedef LPVOID HACCEL;
 
 /* ja:クリップボード */
 #define CF_TEXT        1
+#define CF_BITMAP      2
 #define CF_OEMTEXT     7
+#define CF_DIB         8
 #define CF_UNICODETEXT 13
 
 /* ja:メッセージ */
@@ -775,6 +780,8 @@ LPWSTR WINAPI CharUpperW (LPWSTR lpsz);
 BOOL WINAPI CheckDlgButton (HWND hDlg, INT nIDButton, UINT uCheck);
 BOOL WINAPI CheckRadioButton (HWND hDlg, INT nIDFirstButton, INT nIDLastButton, INT nIDCheckButton);
 BOOL WINAPI ClientToScreen (HWND hWnd, LPPOINT lpPoint);
+BOOL WINAPI ClipCursor (CONST LPRECT lpRect);
+BOOL WINAPI CloseClipboard (VOID);
 BOOL WINAPI CopyRect (LPRECT lprcDst, CONST LPRECT lprcSrc);
 HWND WINAPI CreateDialogIndirectParamA (HINSTANCE hInstance, LPCDLGTEMPLATE lpDialogTemplate, HWND hWndParent, DLGPROC lpDialogFunc, LPARAM dwInitParam);
 HWND WINAPI CreateDialogIndirectParamW (HINSTANCE hInstance, LPCDLGTEMPLATE lpDialogTemplate, HWND hWndParent, DLGPROC lpDialogFunc, LPARAM dwInitParam);
@@ -789,6 +796,7 @@ INT WINAPI DialogBoxIndirectParamA (HINSTANCE hInstance, LPCDLGTEMPLATE lpDialog
 INT WINAPI DialogBoxIndirectParamW (HINSTANCE hInstance, LPCDLGTEMPLATE lpDialogTemplate, HWND hWndParent, DLGPROC lpDialogFunc, LPARAM dwInitParam);
 INT WINAPI DialogBoxParamA (HINSTANCE hInstance, LPCSTR lpTemplateName, HWND hWndParent, DLGPROC lpDialogFunc, LPARAM dwInitParam);
 INT WINAPI DialogBoxParamW (HINSTANCE hInstance, LPCWSTR lpTemplateName, HWND hWndParent, DLGPROC lpDialogFunc, LPARAM dwInitParam);
+BOOL WINAPI EmptyClipboard (VOID);
 BOOL WINAPI EnableWindow (HWND hWnd, BOOL bEnable);
 BOOL WINAPI EndDialog (HWND hDlg, INT nResult);
 BOOL WINAPI EndPaint (HWND hWnd, LPPAINTSTRUCT lpPaint);
@@ -798,6 +806,7 @@ BOOL WINAPI EqualRect (CONST LPRECT lprc1, CONST LPRECT lprc2);
 INT WINAPI GetClassNameA (HWND hWnd, LPSTR lpClassName, INT nMaxCount);
 INT WINAPI GetClassNameW (HWND hWnd, LPWSTR lpClassName, INT nMaxCount);
 BOOL WINAPI GetClientRect (HWND hWnd, LPRECT lpRect);
+BOOL WINAPI GetCursorPos (LPPOINT lpPoint);
 HDC WINAPI GetDC (HWND hWnd);
 HWND WINAPI GetDesktopWindow (VOID);
 INT WINAPI GetDlgCtrlID (HWND hWndCtl);
@@ -805,11 +814,13 @@ HWND WINAPI GetDlgItem (HWND hDlg, INT nIDDlgItem);
 UINT WINAPI GetDlgItemInt (HWND hDlg, INT nIDDlgItem, BOOL *lpTranslated, BOOL bSigned);
 HWND WINAPI GetFocus (VOID);
 INT WINAPI GetKeyboardType (INT nTypeFlag);
+HWND WINAPI GetParent (HWND hWnd);
 INT WINAPI GetScrollPos (HWND hWnd, INT nBar);
 BOOL WINAPI GetScrollRange (HWND hWnd, INT nBar, LPINT lpMinPos, LPINT lpMaxPos);
 DWORD WINAPI GetSysColor (int nIndex);
 HMENU WINAPI GetSystemMenu (HWND hWnd, BOOL bRevert);
 INT WINAPI GetSystemMetrics (INT nIndex);
+HWND WINAPI GetWindow (HWND hWnd, UINT uCmd);
 LONG WINAPI GetWindowLongA (HWND hWnd, INT nIndex);
 LONG WINAPI GetWindowLongW (HWND hWnd, INT nIndex);
 BOOL WINAPI GetWindowRect (HWND hWnd, LPRECT lpRect);
@@ -824,6 +835,7 @@ UINT WINAPI IsDlgButtonChecked (HWND hDlg, INT nIDButton);
 BOOL WINAPI IsRectEmpty (CONST LPRECT lprc);
 BOOL WINAPI IsWindowEnabled (HWND hWnd);
 BOOL WINAPI IsWindowUnicode (HWND hWnd);
+BOOL WINAPI KillTimer (HWND hWnd, UINT uIDEvent);
 HBITMAP WINAPI LoadBitmapA (HINSTANCE hInstance, LPCSTR lpBitmapName);
 HBITMAP WINAPI LoadBitmapW (HINSTANCE hInstance, LPCWSTR lpBitmapName);
 INT WINAPI LoadStringA (HINSTANCE hInstance, UINT uID, LPSTR lpBuffer, INT nBufferMax);
@@ -836,17 +848,21 @@ INT WINAPI MessageBoxExW (HWND hWnd, LPCWSTR lpText, LPCWSTR lpCaption, UINT uTy
 INT WINAPI MessageBoxW (HWND hWnd, LPCWSTR lpText, LPCWSTR lpCaption, UINT uType);
 BOOL WINAPI MoveWindow (HWND hWnd, INT x, INT y, INT nWidth, INT nHeight, BOOL bRepaint);
 BOOL WINAPI OffsetRect (LPRECT lprc, INT dx, INT dy);
+BOOL WINAPI OpenClipboard (HWND hWndNewOwner);
 BOOL WINAPI PtInRect (CONST LPRECT lprc, POINT pt);
 ATOM WINAPI RegisterClassA (CONST LPWNDCLASSA lpWndClass);
 ATOM WINAPI RegisterClassExA (CONST LPWNDCLASSEXA lpWndClassEx);
 ATOM WINAPI RegisterClassExW (CONST LPWNDCLASSEXW lpWndClassEx);
 ATOM WINAPI RegisterClassW (CONST LPWNDCLASSW lpWndClass);
+BOOL WINAPI ReleaseCapture (VOID);
 INT WINAPI ReleaseDC (HWND hWnd, HDC hDC);
 BOOL WINAPI ScreenToClient (HWND hWnd, LPPOINT lpPoint);
 LONG WINAPI SendDlgItemMessageA (HWND hDlg, INT nIDDlgItem, UINT Msg, WPARAM wParam, LPARAM lParam);
 LONG WINAPI SendDlgItemMessageW (HWND hDlg, INT nIDDlgItem, UINT Msg, WPARAM wParam, LPARAM lParam);
 LRESULT WINAPI SendMessageA (HWND hWnd, UINT Msg, WPARAM wParam, LPARAM lParam);
 LRESULT WINAPI SendMessageW (HWND hWnd, UINT Msg, WPARAM wParam, LPARAM lParam);
+HWND WINAPI SetCapture (HWND hWnd);
+HANDLE WINAPI SetClipboardData (UINT uFormat, HANDLE hMem);
 BOOL WINAPI SetDlgItemInt (HWND hDlg, INT nIDDlgItem, UINT uValue, BOOL bSigned);
 BOOL WINAPI SetDlgItemTextA (HWND hDlg, INT nIDDlgItem, LPCSTR lpString);
 BOOL WINAPI SetDlgItemTextW (HWND hDlg, INT nIDDlgItem, LPCWSTR lpString);
@@ -856,6 +872,7 @@ BOOL WINAPI SetRect (LPRECT lprc, int xLeft, int yTop, int xRight, int yBottom);
 BOOL WINAPI SetRectEmpty (LPRECT lprc);
 INT WINAPI SetScrollPos (HWND hWnd, INT nBar, INT nPos, BOOL bRedraw);
 BOOL WINAPI SetScrollRange (HWND hWnd, INT nBar, INT nMinPos, INT nMaxPos, BOOL bRedraw);
+UINT WINAPI SetTimer (HWND hWnd, UINT uIDEvent, UINT uElapse, TIMERPROC lpTimerFunc);
 LONG WINAPI SetWindowLongA (HWND hWnd, INT nIndex, LONG dwNewLong);
 LONG WINAPI SetWindowLongW (HWND hWnd, INT nIndex, LONG dwNewLong);
 BOOL WINAPI SetWindowPos (HWND hWnd, HWND hWndInsertAfter, INT x, INT y, INT cx, INT cy, UINT uFlags);
