@@ -194,18 +194,20 @@ w32ldr_CreateWindowEx (DWORD           dwExStyle,
                          HWND            hWndParent,
                          HINSTANCE       hInstance,
                          const gboolean  widechar);
-  } control[] = {{"BUTTON",            w32ldr_control_create_button},
-                 {"EDIT",              w32ldr_control_create_edit},
-                 {"STATIC",            w32ldr_control_create_static},
-                 {"LISTBOX",           w32ldr_control_create_list},
-                 {"SCROLLBAR",         w32ldr_control_create_scroll},
-                 {"COMBOBOX",          w32ldr_control_create_combo},
-                 {"SysPropertySheet",  w32ldr_control_create_prsht},
-                 {"SysListView32",     w32ldr_control_create_lview},
-                 {"SysTreeView32",     w32ldr_control_create_tview},
-                 {"msctls_progress32", w32ldr_control_create_prgrs},
-                 {"msctls_updown32",   w32ldr_control_create_updwn},
-                 {NULL,                NULL}};
+  } control[] = {{"BUTTON",             w32ldr_control_create_button},
+                 {"EDIT",               w32ldr_control_create_edit},
+                 {"STATIC",             w32ldr_control_create_static},
+                 {"LISTBOX",            w32ldr_control_create_list},
+                 {"SCROLLBAR",          w32ldr_control_create_scroll},
+                 {"COMBOBOX",           w32ldr_control_create_combo},
+                 {"ToolbarWindow32",    w32ldr_control_create_tool},
+                 {"msctls_statusbar32", w32ldr_control_create_stat},
+                 {"SysPropertySheet",   w32ldr_control_create_prsht},
+                 {"SysListView32",      w32ldr_control_create_lview},
+                 {"SysTreeView32",      w32ldr_control_create_tview},
+                 {"msctls_progress32",  w32ldr_control_create_prgrs},
+                 {"msctls_updown32",    w32ldr_control_create_updwn},
+                 {NULL,                 NULL}};
 
   atom = w32ldr_atom_find_name (classname);
   for (i = 0; control[i].func; i++)
@@ -392,7 +394,7 @@ w32ldr_CreateWindowEx (DWORD           dwExStyle,
       if (width != CW_USEDEFAULT && height != CW_USEDEFAULT)
         gtk_window_set_default_size (GTK_WINDOW (widget), width, height);
     }
-  else if (hWndParent)
+  else if (hWndParent && !gtk_widget_get_parent (widget))
     {
       GtkWidget *fixed;
       W32LdrOverlapData *od;
