@@ -57,6 +57,12 @@ typedef struct _HDRVR *HDRVR;
 #define SND_MEMORY    0x0004
 #define SND_LOOP      0x0008
 #define SND_NOSTOP    0x0010
+
+#define TIMERR_BASE    96
+#define TIMERR_NOERROR 0
+#define TIMERR_NOCANDO (TIMERR_BASE+1)
+#define TIMERR_STRUCT  (TIMERR_BASE+33)
+typedef UINT MMRESULT;
 #endif /* W32LDR_HEADER */
 
 
@@ -1189,17 +1195,17 @@ static DWORD WINAPI tid32Message (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, D
 }
 
 
-/* timeBeginPeriod ordinal = 152, argument = 4 temporary */
-static DWORD WINAPI timeBeginPeriod (DWORD dwArgv0)
+/* timeBeginPeriod ordinal = 152, argument = 4 */
+MMRESULT WINAPI timeBeginPeriod (UINT uPeriod)
 {
-  return 0;
+  return TIMERR_NOERROR;
 }
 
 
-/* timeEndPeriod ordinal = 153, argument = 4 temporary */
-static DWORD WINAPI timeEndPeriod (DWORD dwArgv0)
+/* timeEndPeriod ordinal = 153, argument = 4 */
+MMRESULT WINAPI timeEndPeriod (UINT uPeriod)
 {
-  return 0;
+  return TIMERR_NOERROR;
 }
 
 
@@ -1689,8 +1695,8 @@ W32LdrExport winmm_exports[] = {
 {TRUE,  149, "sndPlaySoundA",                sndPlaySoundA},
 {TRUE,  150, "sndPlaySoundW",                sndPlaySoundW},
 {FALSE, 151, "tid32Message",                 tid32Message},
-{FALSE, 152, "timeBeginPeriod",              timeBeginPeriod},
-{FALSE, 153, "timeEndPeriod",                timeEndPeriod},
+{TRUE,  152, "timeBeginPeriod",              timeBeginPeriod},
+{TRUE,  153, "timeEndPeriod",                timeEndPeriod},
 {FALSE, 154, "timeGetDevCaps",               timeGetDevCaps},
 {FALSE, 155, "timeGetSystemTime",            timeGetSystemTime},
 {TRUE,  156, "timeGetTime",                  timeGetTime},
